#!/usr/bin/env python
# -*- coding: utf-8 -*-
import threading  
import time
from Queue import Queue  

class _timerThread(threading.Thread):  
    def __init__(self, t_name,queue,cond,timePrecision):  
        threading.Thread.__init__(self, name=t_name) 
        self.threadtimes = []
        self.threadFunc = {}
        self.lasttimes = {}
        self.isOnceRuns = []
        self.threadFuncRun = {}
        self.queue = queue
        self.timePrecision = timePrecision
    def setNewTimer(self,newobj):
        if newobj.func == None:
            self.threadtimes.remove(newobj.secendtime)
            self.threadFunc[str(newobj.secendtime)] = None
            self.lasttimes[str(newobj.secendtime)] = None
            self.threadFuncRun[str(newobj.secendtime)] = None
            if newobj.secendtime in self.isOnceRuns:
                self.isOnceRuns.remove(newobj.secendtime)
        else:
            if newobj.secendtime in self.threadtimes:
                self.threadFunc[str(newobj.secendtime)] = newobj.func
                self.lasttimes[str(newobj.secendtime)] = int(time.time())
                self.threadFuncRun[str(newobj.secendtime)] = False
                if newobj.isOnce:
                    self.isOnceRuns.append(newobj.secendtime)
            else:
                self.threadtimes.append(newobj.secendtime)
                self.threadFunc[str(newobj.secendtime)] = newobj.func
                self.lasttimes[str(newobj.secendtime)] = int(time.time())
                self.threadFuncRun[str(newobj.secendtime)] = False
                if newobj.isOnce:
                    self.isOnceRuns.append(newobj.secendtime)
    def run(self):
        while(True):
            time.sleep(self.timePrecision)
            if not self.queue.empty():
                objtmp = self.queue.get()
                self.setNewTimer(objtmp)
            timetmp = int(time.time())
            for tx in self.threadtimes:
                if timetmp - self.lasttimes[str(tx)] >= tx:
                    self.lasttimes[str(tx)] = timetmp
                    self.threadFunc[str(tx)](timetmp)
                    self.threadFuncRun[str(tx)] = True
            romveOnces = []
            for tone in self.isOnceRuns:
                if self.threadFuncRun[str(tone)]:
                    romveOnces.append(tone)
            for rmx in romveOnces:
                self.threadtimes.remove(rmx)
                self.threadFunc[str(rmx)] = None
                self.lasttimes[str(rmx)] = None
                self.threadFuncRun[str(rmx)] = None
                self.isOnceRuns.remove(rmx)
        self.condition.release()
        
class _timerObj():
    def __init__(self,secendt,funct,isOnce = False):
        self.secendtime = secendt
        self.func = funct
        self.isOnce = isOnce

class pytimer():
    #timePrecision为时间精度，时间精度越高越占CPU时间，默认为100毫秒精度
    def __init__(self,timePrecision = 0.1):
        self.queue = Queue()   
        self.cond = threading.Condition()
        self.t_thread = _timerThread(str(int(time.time())),self.queue, self.cond,timePrecision) 
        self._timers = []
        self._initTimer()
    def _initTimer(self):
        self.t_thread.setDaemon(True)
        self.t_thread.start()
    def getTimers(self):
        return self._timers
    def setTimer(self,secendTime,Func,isOnce = False):
        objtmp = _timerObj(secendTime,Func,isOnce)
        self._timers.append(secendTime)
        self.queue.put(objtmp)
    def removeTimer(self,secendTime):
        objtmp = _timerObj(secendTime,None)
        self._timers.remove(secendTime)
        self.queue.put(objtmp)
    


def main():  
    def timerCallBack(timex):
        print timex
    timerx = pytimer()
    timerx.setTimer(2, timerCallBack)
    while(True):
        time.sleep(1)
        pass
if __name__ == '__main__':  
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Date    : 2017-02-22 09:44:42

import dbm
import json
import time

dbpth = './db/keysdb'

class DBMObj(object):
    """docstring for ClassName"""
    def __init__(self, pth):
        self.dbpth = pth
        self.dbtimepth = pth + 'time'

    def inset(self,key,value):
        db = dbm.open(self.dbpth, 'c')
        db[key] = value
        db.close()
        tdb = dbm.open(self.dbtimepth, 'c')
        if key in tdb:
            timedic = json.loads(tdb[key])
            timedic['last'] = int(time.time())
            tdb[key] = json.dumps(timedic)
        else:
            timedic = {'create':int(time.time()),'last':int(time.time())}
            tdb[key] = json.dumps(timedic)
        tdb.close()

    def insetList(self,keys,values):
        if len(keys) == len(values):
            db = dbm.open(self.dbpth, 'c')
            tdb = dbm.open(self.dbtimepth, 'c')
            for i in range(len(keys)):
                db[keys[i]] = values[i]
                key = keys[i]
                if keys[i] in tdb:
                    timedic = json.loads(tdb[key])
                    timedic['last'] = int(time.time())
                    tdb[key] = json.dumps(timedic)
                else:
                    timedic = {'create':int(time.time()),'last':int(time.time())}
                    tdb[key] = json.dumps(timedic)
            tdb.close()
            db.close()

            return True
        else:
            return False

    def delet(self,key):
        db = dbm.open(self.dbpth, 'c')
        if key in db:
            del db[key]
            tdb = dbm.open(self.dbtimepth, 'c')
            del tdb[key]
            tdb.close()
        db.close()

    def update(self,key,value):
        db = dbm.open(self.dbpth, 'c')
        db[key] = value
        db.close()
        tdb = dbm.open(self.dbtimepth, 'c')
        if key in tdb:
            timedic = json.loads(tdb[key])
            timedic['last'] = int(time.time())
            tdb[key] = json.dumps(timedic)
        else:
            timedic = {'create':int(time.time()),'last':int(time.time())}
            tdb[key] = json.dumps(timedic)
        tdb.close()

    def select(self,key):
        db = dbm.open(self.dbpth, 'c')
        out = None
        if key in db:
            out = db[key]
        db.close()
        return out

    def allKeys(self):
        db = dbm.open(self.dbpth, 'c')
        keys = db.keys()
        db.close()
        return keys
        
    def getDBDatas(self):
        db = dbm.open(self.dbpth, 'c')
        data = {}
        for k in db.keys():
            data[k] = json.loads(db[k])
        db.close()
        return data
def main():
    tobj = DBMObj(dbpth)
    print(tobj)
    print(tobj.allKeys())
    tobj.inset('mykey2', '111')
    print(tobj.select('mykey'))
    tobj.delet('mykey')
    print(tobj.select('mykey'))
    print(tobj.select('mykey2'))
    tobj.update('mykey2', 'dddx')
    print(tobj.select('mykey2'))
    # delet('mykey2')
    print(tobj.allKeys())

if __name__=="__main__":  
    main()




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Date    : 2016-12-07 09:28:00
# @Link    : http://fengmm521.blog.163.com
# @Version : $Id$
#这里使用pycrypto‎库
#按照方法:easy_install pycrypto‎
 
from Crypto.Cipher import AES
from binascii import b2a_hex,a2b_hex
 
class prpcrypt():
    def __init__(self,key):
        self.key = key
        self.mode = AES.MODE_CBC
     
    #加密函数，如果text不足16位就用空格补足为16位，
    #如果大于16当时不是16的倍数，那就补足为16的倍数。
    def encrypt(self,text):
        cryptor = AES.new(self.key,self.mode,b'0000000000000000')
        #这里密钥key 长度必须为16（AES-128）,
        #24（AES-192）,或者32 （AES-256）Bytes 长度
        #目前AES-128 足够目前使用
        length = 16
        count = len(text)
        if count < length:
            add = (length-count)
            #\0 backspace
            text = text + (b'\0' * add)
        elif count > length:
            add = (length-(count % length))
            text = text + (b'\0' * add)
        self.ciphertext = cryptor.encrypt(text)
        #因为AES加密时候得到的字符串不一定是ascii字符集的，输出到终端或者保存时候可能存在问题
        #所以这里统一把加密后的字符串转化为16进制字符串
        return b2a_hex(self.ciphertext)
     
    #解密后，去掉补足的空格用strip() 去掉
    def decrypt(self,text):
        cryptor = AES.new(self.key,self.mode,b'0000000000000000')
        plain_text  = cryptor.decrypt(a2b_hex(text))
        return plain_text.rstrip(b'\0')
 
if __name__ == '__main__':
    pc = prpcrypt('keyskeyskeyskeys') #初始化密钥
    import sys
    e = pc.encrypt('test....ssdfaaaa')
    if len(sys.argv) > 1:
        e = pc.encrypt(sys.argv[1]) #加密
    d = pc.decrypt(e) #解密
    print("加密:",e)
    print("解密:",d)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Date    : 2017-12-09 22:36:40
# @Author  : Your Name (you@example.org)
# @Link    : http://example.org
# @Version : $Id$

import os, sys
import time
import platform
import zlib

#http://www.cnblogs.com/freeliver54/archive/2008/04/08/1142356.html

#http://blog.csdn.net/xtx1990/article/details/7288903 

class SystemMsgObj(object):
    """docstring for SystemMsgObj"""
    def __init__(self):
        super(SystemMsgObj, self).__init__()
        self.sysversion = platform.version()
        self.sysplatform = platform.platform()
        self.sysSystem = platform.system()
        self.ver = ''
        self.ostype = 0        #1.windows,2.mac,3.linux
        if self.sysSystem == 'Windows':  #mac系统
            self.ostype = 1        #1.windows,2.mac,3.linux
            self.ver = platform.win32_ver()
        elif self.sysSystem == 'Darwin':
            self.ostype = 2
            self.ver = platform.mac_ver()
            
        elif self.sysSystem == 'Linux':
            self.ostype = 3
            self.ver = platform.linux_distribution()
        self.c = None
        self.sysMsg = {}
        self.sysMsg['osversion'] = str(self.sysversion)
        self.sysMsg['osplatform'] = str(self.sysplatform)
        self.sysMsg['os'] = str(self.sysSystem)
        self.sysMsg['ver'] = self.ver
        self.sysMsg['ostype'] = self.ostype
        if self.ostype == 1:
            import wmi
            self.c = wmi.WMI()
            self.initWinSystemHardMsg()
        elif self.ostype == 2:
            self.initMacSystemHardMsg()
        elif self.ostype == 3:
            self.initLinuxSystemHardMsg()

        self.getUserHardID()
    def initWinSystemHardMsg(self):
        self.sysMsg['cpu'] = self._printCPU()
        self.sysMsg['mainboard'] = self._printMain_board()
        self.sysMsg['BIOS'] = self._printBIOS()
        self.sysMsg['disk'] = self._printDisk()
        self.sysMsg['memory'] = self._printPhysicalMemory()
        self.sysMsg['battery'] = self._printBattery()
        self.sysMsg['MacAddr'] = self._printMacAddress()
        self.getUserHardID()
        return self.sysMsg
    def initMacSystemHardMsg(self):
        pass
    def initLinuxSystemHardMsg(self):
        pass

    def getSysMsg(self):
        return self.sysMsg

    def getUserHardID(self):
        if self.ostype == 1: #windwos
            self.sysMsg['userHardID'] = ''
            #windows下以电脑主板的UUID为编号
            #当主板UUID不存存或者无效时，使用容量最大硬盘的UUID + CPUID的MD5值
            #如果硬盘UUID无法获取，使用网卡MAC地址 + CPUID
        elif self.ostype == 2: #mac
            self.sysMsg['userHardID'] = ''

        elif self.ostype == 3: #linux

            self.sysMsg['userHardID'] = ''

    #处理器
    def _printCPU(self):
        tmpdict = {}
        tmpdict["CpuCores"] = 0
        for cpu in self.c.Win32_Processor():     
            tmpdict["cpuid"] = cpu.ProcessorId.strip()
            tmpdict["CpuType"] = cpu.Name
            tmpdict['systemName'] = cpu.SystemName
            try:
                tmpdict["CpuCores"] = cpu.NumberOfCores
            except:
                tmpdict["CpuCores"] += 1
            tmpdict["CpuClock"] = cpu.MaxClockSpeed 
            tmpdict['DataWidth'] = cpu.DataWidth
        # print tmpdict
        return  tmpdict

    #主板
    def _printMain_board(self):
        boards = []
        # print len(c.Win32_BaseBoard()):
        for board_id in self.c.Win32_BaseBoard():
            tmpmsg = {}
            tmpmsg['UUID'] = board_id.qualifiers['UUID'][1:-1]   #主板UUID,有的主板这部分信息取到为空值，ffffff-ffffff这样的
            tmpmsg['SerialNumber'] = board_id.SerialNumber                #主板序列号
            tmpmsg['Manufacturer'] = board_id.Manufacturer       #主板生产品牌厂家
            tmpmsg['Product'] = board_id.Product                 #主板型号
            boards.append(tmpmsg)
        print boards
        return boards

    #BIOS
    def _printBIOS(self):
        bioss = []
        for bios_id in self.c.Win32_BIOS():
            tmpmsg = {}
            tmpmsg['BiosCharacteristics'] = bios_id.BiosCharacteristics   #BIOS特征码
            tmpmsg['version'] = bios_id.Version                           #BIOS版本
            tmpmsg['Manufacturer'] = bios_id.Manufacturer.strip()                 #BIOS固件生产厂家
            tmpmsg['ReleaseDate'] = bios_id.ReleaseDate                   #BIOS释放日期
            tmpmsg['SMBIOSBIOSVersion'] = bios_id.SMBIOSBIOSVersion       #系统管理规范版本
            bioss.append(tmpmsg)
        print bioss
        return bioss

    #硬盘
    def _printDisk(self):
        disks = []
        for disk in self.c.Win32_DiskDrive():
            # print disk.__dict__
            tmpmsg = {}
            tmpmsg['SerialNumber'] = disk.SerialNumber.strip()
            tmpmsg['DeviceID'] = disk.DeviceID
            tmpmsg['Caption'] = disk.Caption
            tmpmsg['Size'] = disk.Size
            tmpmsg['UUID'] = disk.qualifiers['UUID'][1:-1]
            disks.append(tmpmsg)
        for d in disks:
            print d
        return disks

    #内存
    def _printPhysicalMemory(self):
        memorys = []
        for mem in self.c.Win32_PhysicalMemory():
            tmpmsg = {}
            tmpmsg['UUID'] = mem.qualifiers['UUID'][1:-1]
            tmpmsg['BankLabel'] = mem.BankLabel
            tmpmsg['SerialNumber'] = mem.SerialNumber.strip()
            tmpmsg['ConfiguredClockSpeed'] = mem.ConfiguredClockSpeed
            tmpmsg['Capacity'] = mem.Capacity
            tmpmsg['ConfiguredVoltage'] = mem.ConfiguredVoltage
            memorys.append(tmpmsg)
        for m in memorys:
            print m
        return memorys

    #电池信息，只有笔记本才会有电池选项
    def _printBattery(self):
        isBatterys = False
        for b in self.c.Win32_Battery():
            isBatterys = True
        return isBatterys

    #网卡mac地址：
    def _printMacAddress(self):
        macs = []
        for n in  self.c.Win32_NetworkAdapter():
            mactmp = n.MACAddress
            if mactmp and len(mactmp.strip()) > 5:
                tmpmsg = {}
                tmpmsg['MACAddress'] = n.MACAddress
                tmpmsg['Name'] = n.Name
                tmpmsg['DeviceID'] = n.DeviceID
                tmpmsg['AdapterType'] = n.AdapterType
                tmpmsg['Speed'] = n.Speed
                macs.append(tmpmsg)
        print macs
        return macs

def main():
    ostmp = SystemMsgObj()
    osmsg = ostmp.getSysMsg()
    print osmsg
if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import urllib2
import chardet
import requests


def conventStrTOUtf8(oldstr):
    try:
        nstr = oldstr.encode("utf-8")
        return nstr
    except Exception as e:
        print('nstr do not encode utf-8')
    cnstrtype = chardet.detect(oldstr)['encoding']
    utf8str =  oldstr.decode(cnstrtype).encode('utf-8')
    return utf8str

def postDataToURL(purl,data):
    if purl[0:5] == 'https':
        response = requests.post(purl,data=data,verify=False)
        dat = response.text
        return dat
    else:
        response = requests.post(purl,data=data)
        dat = response.text
        return dat

def getUrl(purl):
    try:
        if purl[0:5] == 'https':
            res = requests.get(purl, verify=False)
            # print(res.text)
            return res.text
        else:
            res = requests.get(purl)
            # print(res.text)
            return res.text
    except Exception as e:
        print(e)
    return None

if __name__ == '__main__':
    pass


#!/usr/bin/env python
# -*- coding: utf-8 -*-
import time

def getAverageLineData(datas,pAver = 3,didx = 4):
    #[1517536380000,142.443,142.443,142,142,3486,244.8654307]
    ##时间戳，开，高，低，收，交易量，交易量转化为BTC或LTC数量
    outs = []
    for n in range(len(datas)):
        d = datas[n]
        tmps = [d[0]]
        if n < pAver -1:
            dtmp = datas[0:n+1]
            vtmp = [x[didx] for x in dtmp]
            mean = np.mean(vtmp)
            tmps.append(mean)
        else:
            dtmp = datas[n - pAver+1:n+1]
            vtmp = [x[didx] for x in dtmp]
            mean = np.mean(vtmp)
            tmps.append(mean)
        outs.append(tmps)
    return outs


if __name__ == '__main__':
    # print datetime.datetime.utcnow()
    # print timestamp_utc_now()
    # print timestamp2datetime(int(time.time()),True)
    tmpdat = '2017_7_17'
    print(getDateDaysFromOneDate(tmpdat))
    # outstr = timestamp2datetime(int(time.time() + 60 * 5),True)
    # print outstr


#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys
import types
# import pyctest
#http://python3-cookbook.readthedocs.io/zh_CN/latest/c10/p11_load_modules_from_remote_machine_by_hooks.html

def loadModeFromFile(fname = 'pyctest.py',modeName = 'pyctest'):
    f = open(fname,'r')
    pycode = f.read()
    f.close()
    m = types.ModuleType(modeName)
    exec pycode in m.__dict__
    m = sys.modules.setdefault(modeName, m)
    # print pyctest
    # print sys.modules['pyctest'].__name__
    # # print sys.modules['pyctest'].__file__
    # print sys.modules['pyctest'].__package__
    return m

def main():
    # print sys.modules
    # print sys.modules.keys()
    
    # print sys.modules['pyctest'].__path__
    # print sys.modules['pyctest'].__loader__

    m = loadModeFromFile()
    print(m.pyctest())
    print(m.xxx)

    testobj = m.TESTObj('hahaha')
    testobj.showP()


if __name__ == '__main__':
    main()